@@ -18,11 +18,10 @@ THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABI
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
 """
-from __future__ import unicode_literals
 import os
 from .platform_window_focus import platform_window_focus
 from .custom_app import PipeApp
-from .. import rummage_dialog
+from ..dialogs import rummage_dialog
 from ..settings import Settings
 import wx
 
