@@ -32,7 +32,7 @@ class SavedSearchList(DynamicList):
 
         self.localize()
 
-        super(SavedSearchList, self).__init__(
+        super().__init__(
             parent,
             [
                 self.NAME,
@@ -59,10 +59,11 @@ class SavedSearchList(DynamicList):
     def create_image_list(self):
         """Create image list."""
 
+        self.tint = data.RGBA(self.GetForegroundColour().Get())
         self.images = wx.ImageList(16, 16)
-        self.glass = self.images.Add(data.get_bitmap('glass.png'))
-        self.sort_up = self.images.Add(data.get_bitmap('su.png'))
-        self.sort_down = self.images.Add(data.get_bitmap('sd.png'))
+        self.glass = self.images.Add(data.get_bitmap('glass.png', tint=self.tint))
+        self.sort_up = self.images.Add(data.get_bitmap('arrow_up.png', tint=self.tint, alpha=0.3))
+        self.sort_down = self.images.Add(data.get_bitmap('arrow_down.png', tint=self.tint, alpha=0.3))
         self.AssignImageList(self.images, wx.IMAGE_LIST_SMALL)
 
     def get_item_text(self, item, col, absolute=False):
@@ -70,4 +71,4 @@ class SavedSearchList(DynamicList):
 
         if not absolute:
             item = self.itemIndexMap[item]
-        return self.itemDataMap[item][col]
+        return self.itemDataMap[item][self.get_real_col(col)]
