@@ -4,10 +4,8 @@ Notify macOS.
 Copyright (c) 2013 - 2016 Isaac Muse <isaacmuse@gmail.com>
 License: MIT
 """
-from __future__ import unicode_literals
 import subprocess
-import traceback
-from os.path import exists
+import os
 # ```
 # import ctypes
 # import ctypes.util
@@ -66,7 +64,7 @@ def _is_ver_okay():
         return False
 
 
-class Options(object):
+class Options:
     """Notification options."""
 
     notify = None
@@ -74,6 +72,7 @@ class Options(object):
     terminal_notifier = None
     app_name = ""
     icon = None
+    sound = None
 
     @classmethod
     def clear(cls):
@@ -84,20 +83,34 @@ class Options(object):
         cls.terminal_notifier = None
         cls.app_name = ""
         cls.icon = None
+        cls.sound = None
 
 
-def alert(sound=None):
+def _alert(sound=None):
     """Play an alert sound for the OS."""
 
-    subprocess.call(["afplay", "/System/Library/Sounds/Glass.aiff"])
-    # ```
-    # pool = _callmethod(_callmethod(NSAutoreleasePool, "alloc"), "init")
-    # snd = _nsstring(sound if sound is not None else "Glass")
-    # soundobj = _callmethod(NSSound, "soundNamed:", snd)
-    # _callmethod(soundobj, "play")
-    # _callmethod(pool, "drain")
-    # del pool
-    # ```
+    if sound is None and Options.sound is not None:
+        sound = Options.sound
+
+    try:
+        if sound is not None:
+            subprocess.call(["afplay", sound])
+        # ```
+        # pool = _callmethod(_callmethod(NSAutoreleasePool, "alloc"), "init")
+        # snd = _nsstring(sound if sound is not None else "Glass")
+        # soundobj = _callmethod(NSSound, "soundNamed:", snd)
+        # _callmethod(soundobj, "play")
+        # _callmethod(pool, "drain")
+        # del pool
+        # ```
+    except Exception:
+        pass
+
+
+def alert():
+    """Alert."""
+
+    _alert()
 
 
 @staticmethod
@@ -113,7 +126,8 @@ def notify_osx_call(title, message, sound, fallback):
     """Notifications for macOS."""
 
     try:
-        assert(Options.terminal_notifier is not None and exists(Options.terminal_notifier))
+        if Options.terminal_notifier is None or not os.path.exists(Options.terminal_notifier):
+            raise ValueError("Specified terminal notifier does not appear to be valid")
         # Show Notification here
         params = [Options.terminal_notifier, "-title", Options.app_name, "-timeout", "5"]
         if message is not None:
@@ -124,53 +138,53 @@ def notify_osx_call(title, message, sound, fallback):
             params += ["-sender", Options.sender]
         if Options.icon is not None:
             params += ["-appIcon", Options.icon]
-        if sound:
-            params += ["-sound", "Glass"]
         subprocess.Popen(params)
 
-        # if sound:
-        #     # Play sound if desired
-        #     alert()
+        if sound:
+            # Play sound if desired
+            alert()
     except Exception:
-        print(traceback.format_exc())
         # Fallback notification
         fallback(title, message, sound)
 
 
-def setup(app_name, icon, *args):
+def setup(app_name, icon, **kwargs):
     """Setup."""
 
     term_notify = None
     sender = None
 
-    if len(args) and len(args[0]) == 2:
-        term_notify = args[0][0]
-        sender = args[0][1]
-        notify_icon = icon
+    term_notify = kwargs.get('term_notify')
+    sender = kwargs.get('sender')
+    sound = kwargs.get('sound')
+    if sound is not None and os.path.exists(sound):
+        Options.sound = sound
+    notify_icon = icon
 
-        if term_notify is not None and isinstance(term_notify, binary_type):
-            term_notify = term_notify.decode('utf-8')
+    if term_notify is not None and isinstance(term_notify, binary_type):
+        term_notify = term_notify.decode('utf-8')
 
-        if sender is not None and isinstance(sender, binary_type):
-            sender = sender.decode('utf-8')
+    if sender is not None and isinstance(sender, binary_type):
+        sender = sender.decode('utf-8')
 
-        if _is_ver_okay():
-            notify_icon = None
-        elif notify_icon is not None and isinstance(notify_icon, binary_type):
-            notify_icon = notify_icon.decode('utf-8')
+    if _is_ver_okay():
+        notify_icon = None
+    elif notify_icon is not None and isinstance(notify_icon, binary_type):
+        notify_icon = notify_icon.decode('utf-8')
 
     Options.app_name = app_name
 
     try:
-        assert(term_notify is not None and exists(term_notify))
+        if term_notify is None or not os.path.exists(term_notify):
+            raise ValueError("Terminal notifier does not appear to be available")
         Options.terminal_notifier = term_notify
         if sender is not None:
             Options.sender = sender
-        if notify_icon is not None and exists(notify_icon):
+        if notify_icon is not None and os.path.exists(notify_icon):
             Options.icon = notify_icon
         Options.notify = notify_osx_call
     except Exception:
-        print(traceback.format_exc())
+        pass
 
 
 def destroy():
