@@ -4,7 +4,6 @@ Notify windows.
 Copyright (c) 2013 - 2016 Isaac Muse <isaacmuse@gmail.com>
 License: MIT
 """
-from __future__ import unicode_literals
 import traceback
 import winsound
 import ctypes
@@ -35,18 +34,19 @@ WS_SYSMENU = 524288
 CW_USEDEFAULT = -2147483648
 WM_USER = 1024
 
-NIM_ADD = 0
-NIM_MODIFY = 1
-NIM_DELETE = 2
-NIM_SETVERSION = 4
-NIF_ICON = 2
-NIF_MESSAGE = 1
-NIF_TIP = 4
-NIIF_INFO = 1
-NIIF_WARNING = 2
-NIIF_ERROR = 3
-NIF_INFO = 16
+NIM_ADD = 0x00
+NIM_MODIFY = 0x01
+NIM_DELETE = 0x02
+NIM_SETVERSION = 0x04
+NIF_MESSAGE = 0x01
+NIF_ICON = 0x02
+NIF_TIP = 0x04
+NIF_INFO = 0x10
 NIF_SHOWTIP = 0x80
+NIIF_INFO = 0x1
+NIIF_WARNING = 0x2
+NIIF_ERROR = 0x3
+NIIF_NOSOUND = 0x10
 
 
 class WndClassEx(ctypes.Structure):
@@ -96,11 +96,12 @@ class NotifyIconDataV3(ctypes.Structure):
     _fields_ = NotifyIconData._fields_[:-1]  # noqa
 
 
-class Options(object):
+class Options:
     """Notification options."""
 
     notify = None
     instance = None
+    sound = None
 
     @classmethod
     def clear(cls):
@@ -108,16 +109,29 @@ class Options(object):
 
         cls.notify = None
         cls.instance = None
+        cls.sound = None
 
 
-def alert(sound=None):
+def _alert(sound=None):
     """Play an alert sound for the OS."""
 
-    snd = sound if sound is not None else "*"
-    winsound.PlaySound(snd, winsound.SND_ALIAS)
+    if sound is None and Options.sound is not None:
+        sound = Options.sound
+
+    try:
+        if sound:
+            winsound.PlaySound(sound, winsound.SND_FILENAME)
+    except Exception:
+        pass
 
 
-class WinNotifyLevel(object):
+def alert():
+    """Alert."""
+
+    _alert()
+
+
+class WinNotifyLevel:
     """Windows notification level."""
 
     ICON_INFORMATION = 0x01
@@ -138,7 +152,7 @@ def notify_win_fallback(title, message, sound, icon, fallback):
     fallback(title, message, sound)
 
 
-class WindowsNotify(object):
+class WindowsNotify:
     """Windows notification class."""
 
     window_handle = None
@@ -200,7 +214,8 @@ class WindowsNotify(object):
 
         icon_flags = LR_LOADFROMFILE | LR_DEFAULTSIZE
         try:
-            assert icon is not None
+            if icon is None:
+                raise ValueError("Icon is not available")
             hicon = ctypes.windll.user32.LoadImageW(
                 self.hinst, icon,
                 IMAGE_ICON,
@@ -267,7 +282,7 @@ class WindowsNotify(object):
         res.uVersion = 3 if self.is_xp else 4
         res.szInfo = msg[:256]
         res.szInfoTitle = title[:64]
-        res.dwInfoFlags = icon_level
+        res.dwInfoFlags = icon_level | NIIF_NOSOUND
 
         self.show_icon(res)
 
@@ -322,11 +337,16 @@ def NotifyWin(title, msg, sound, icon, fallback):
     Options.instance.show_notification(title, msg, sound, icon, fallback)
 
 
-def setup(app_name, icon, *args):
+def setup(app_name, icon, **kwargs):
     """Setup."""
 
+    sound = kwargs.get('sound')
+    if sound is not None and os.path.exists(sound):
+        Options.sound = sound
+
     try:
-        assert(icon is not None and os.path.exists(icon))
+        if icon is None or not os.path.exists(icon):
+            raise ValueError("Icon does not appear to be valid")
     except Exception:
         icon = None
 
