@@ -19,7 +19,6 @@ THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABI
 CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 IN THE SOFTWARE.
 """
-from __future__ import unicode_literals
 import sys
 import codecs
 import mmap
@@ -33,8 +32,7 @@ from backrefs import bre
 from collections import deque
 from . import text_decode
 from wcmatch import wcmatch
-from .file_times import getmtime, getctime
-from .. import util
+from . import util
 try:
     from backrefs import bregex
     import regex
@@ -75,14 +73,16 @@ PROCESS_BINARY = 0x1000000  # Process binary files
 TRUNCATE_LINES = 0x2000000  # Truncate context lines to 120 chars
 BACKUP = 0x4000000          # Backup files on replace
 BACKUP_FOLDER = 0x8000000   # Backup to folder
+FOLLOW_LINKS = 0x10000000   # Follow symlinks
 
 # Fnmatch/Glob flags
-EXTMATCH = 0x10000000       # Match with extended patterns +(...) etc.
-BRACE = 0x20000000          # Expand braces a{b,c} -> ab ac
-FILECASE = 0x40000000       # File case sensitivity
-DIRPATHNAME = 0x80000000    # Full directory exclude path match
-FILEPATHNAME = 0x100000000  # Full file name path match
-GLOBSTAR = 0x200000000      # Use globstar (**) in full paths
+EXTMATCH = 0x100000000       # Match with extended patterns +(...) etc.
+BRACE = 0x200000000          # Expand braces a{b,c} -> ab ac
+FILECASE = 0x400000000       # File case sensitivity
+DIRPATHNAME = 0x800000000    # Full directory exclude path match
+FILEPATHNAME = 0x1000000000  # Full file name path match
+GLOBSTAR = 0x2000000000      # Use globstar (**) in full paths
+MATCHBASE = 0x4000000000     # Match base names when no slashes are present (full path)
 
 RE_MODE = 0
 BRE_MODE = 1
@@ -90,8 +90,8 @@ REGEX_MODE = 2
 BREGEX_MODE = 3
 
 SEARCH_MASK = 0x1FFFF
-FILE_MASK = 0x3FFFE0000
-FNMATCH_FLAGS = 0x3F0000000
+FILE_MASK = 0x7FFFFE0000
+FNMATCH_FLAGS = 0x3F00000000
 
 RE_MODES = (RE_MODE, BRE_MODE)
 REGEX_MODES = (REGEX_MODE, BREGEX_MODE)
@@ -300,7 +300,7 @@ class ErrorRecord(namedtuple('ErrorRecord', ['error'])):
     """A record for non-file related errors."""
 
 
-class Search(object):
+class Search:
     """Search setup object."""
 
     def __init__(self, replace=False):
@@ -341,7 +341,7 @@ class Search(object):
         return len(self._entry)
 
 
-class ReplacePlugin(object):
+class ReplacePlugin:
     """Rummage replace plugin."""
 
     def __init__(self, file_info, flags):
@@ -394,7 +394,7 @@ class ReplacePlugin(object):
         return m.group(0)
 
 
-class _RummageFileContent(object):
+class _RummageFileContent:
     """Either return a string or memory map file object."""
 
     def __init__(self, name, size, encoding, file_content=None):
@@ -463,7 +463,7 @@ class _RummageFileContent(object):
                 return self.file_map
 
 
-class _FileSearch(object):
+class _FileSearch:
     """Search for files."""
 
     hex_tx_table = ("\ufffd" * 32) + "".join(chr(c) for c in range(32, 127)) + ("\ufffd" * 129)
@@ -1118,8 +1118,8 @@ class _DirWalker(wcmatch.WcMatch):
     """Walk the directory."""
 
     def on_init(
-        self, file_regex_match, folder_regex_exclude_match, size, modified, created,
-        backup_location, backup_to_folder, regex_mode=RE_MODE, regex_ver=0
+        self, file_regex_match=False, folder_regex_exclude_match=False, size=None, modified=None, created=None,
+        backup_location='', backup_to_folder=False, regex_mode=RE_MODE, regex_ver=0
     ):
         self.file_regex_match = file_regex_match
         self.folder_regex_exclude_match = folder_regex_exclude_match
@@ -1193,8 +1193,6 @@ class _DirWalker(wcmatch.WcMatch):
         times_okay = False
         mod_okay = False
         cre_okay = False
-        self.modified_time = getmtime(pth)
-        self.created_time = getctime(pth)
         if self.modified is None:
             mod_okay = True
         else:
@@ -1211,7 +1209,6 @@ class _DirWalker(wcmatch.WcMatch):
         """Verify file size meets requirements."""
 
         size_okay = False
-        self.current_size = os.path.getsize(pth)
         if self.size is None:
             size_okay = True
         else:
@@ -1238,11 +1235,28 @@ class _DirWalker(wcmatch.WcMatch):
 
         return is_backup
 
+    def compare_file(self, filename):
+        """Compare filename."""
+
+        if self.file_regex_match:
+            return self.file_check.match(filename)
+        else:
+            return super().compare_file(filename)
+
+    def compare_directory(self, directory):
+        """Compare folder."""
+
+        if self.folder_regex_exclude_match:
+            return not self.folder_exclude_check.match(directory)
+        else:
+            return super().compare_directory(directory)
+
     def on_validate_file(self, base, name):
         """Validate file override."""
 
         valid = not self._is_backup(name)
         fullname = os.path.join(base, name)
+        self.created_time, self.modified_time, self.current_size = util.get_stat(fullname)
         if valid:
             valid = self._is_size_okay(fullname)
         if valid:
@@ -1294,11 +1308,11 @@ class _DirWalker(wcmatch.WcMatch):
         )
 
 
-class Rummage(object):
+class Rummage:
     """Perform the rummaging."""
 
     def __init__(
-        self, target, searches, file_pattern=None, folder_exclude=None,
+        self, target, searches, file_pattern=None, folder_exclude=None, limit=1000,
         flags=0, context=(0, 0), max_count=None, encoding=None, size=None,
         modified=None, created=None, backup_location=None, regex_mode=RE_MODE,
         encoding_options=None
@@ -1326,13 +1340,21 @@ class Rummage(object):
         if self.file_flags & BRACE:
             self.wcmatch_flags |= wcmatch.B
         if self.file_flags & FILECASE:
-            self.wcmatch_flags |= wcmatch.F
+            self.wcmatch_flags |= wcmatch.C
         if self.file_flags & DIRPATHNAME:
             self.wcmatch_flags |= wcmatch.DP
         if self.file_flags & FILEPATHNAME:
             self.wcmatch_flags |= wcmatch.FP
         if self.file_flags & GLOBSTAR:
             self.wcmatch_flags |= wcmatch.G
+        if self.file_flags & MATCHBASE:
+            self.wcmatch_flags |= wcmatch.X
+        if self.file_flags & RECURSIVE:
+            self.wcmatch_flags |= wcmatch.RV
+        if self.file_flags & SHOW_HIDDEN:
+            self.wcmatch_flags |= wcmatch.HD
+        if self.file_flags & FOLLOW_LINKS:
+            self.wcmatch_flags |= wcmatch.SL
 
         self.context = context
         self.encoding = self._verify_encoding(encoding) if encoding is not None else None
@@ -1353,65 +1375,69 @@ class Rummage(object):
         self.path_walker = None
         self.is_binary = False
         self.files = deque()
+        self.setup_error = None
 
-        # Initialize search objects:
-        # - `_DirWalker` for if target is a folder
-        # - Append `FileAttrRecord` if target is a file or buffer
-        if not self.buffer_input and os.path.isdir(self.target):
-            self.path_walker = _DirWalker(
-                self.target,
-                file_pattern,
-                folder_exclude,
-                bool(self.file_flags & RECURSIVE),
-                bool(self.file_flags & SHOW_HIDDEN),
-                self.wcmatch_flags,
-                file_regex_match,
-                dir_regex_match,
-                size,
-                modified,
-                created,
-                self.backup_location if bool(self.file_flags & BACKUP) else None,
-                bool(self.file_flags & BACKUP_FOLDER),
-                self.regex_mode,
-                0 if flags & VERSION1 else 1
-            )
-        elif not self.buffer_input and os.path.isfile(self.target):
-            try:
+        try:
+            # Initialize search objects:
+            # - `_DirWalker` for if target is a folder
+            # - Append `FileAttrRecord` if target is a file or buffer
+            if not self.buffer_input and os.path.isdir(self.target):
+                self.path_walker = _DirWalker(
+                    self.target,
+                    file_pattern=file_pattern,
+                    exclude_pattern=folder_exclude,
+                    flags=self.wcmatch_flags,
+                    limit=limit,
+                    file_regex_match=file_regex_match,
+                    folder_regex_exclude_match=dir_regex_match,
+                    size=size,
+                    modified=modified,
+                    created=created,
+                    backup_location=self.backup_location if bool(self.file_flags & BACKUP) else None,
+                    backup_to_folder=bool(self.file_flags & BACKUP_FOLDER),
+                    regex_mode=self.regex_mode,
+                    regex_ver=0 if flags & VERSION1 else 1
+                )
+            elif not self.buffer_input and os.path.isfile(self.target):
+                try:
+                    c_time, m_time = util.get_stat(self.target)
+                    self.files.append(
+                        FileAttrRecord(
+                            self.target,
+                            os.path.splitext(self.target)[1].lower().lstrip('.'),
+                            os.path.getsize(self.target),
+                            m_time,
+                            c_time,
+                            False,
+                            None
+                        )
+                    )
+                except Exception:
+                    self.files.append(
+                        FileAttrRecord(
+                            self.target,
+                            None,
+                            None,
+                            None,
+                            None,
+                            False,
+                            get_exception()
+                        )
+                    )
+            elif self.buffer_input:
                 self.files.append(
                     FileAttrRecord(
-                        self.target,
-                        os.path.splitext(self.target)[1].lower().lstrip('.'),
-                        os.path.getsize(self.target),
-                        getmtime(self.target),
-                        getctime(self.target),
+                        None,
+                        None,
+                        len(self.target),
+                        ctime(),
+                        ctime(),
                         False,
                         None
                     )
                 )
-            except Exception:
-                self.files.append(
-                    FileAttrRecord(
-                        self.target,
-                        None,
-                        None,
-                        None,
-                        None,
-                        False,
-                        get_exception()
-                    )
-                )
-        elif self.buffer_input:
-            self.files.append(
-                FileAttrRecord(
-                    None,
-                    None,
-                    len(self.target),
-                    ctime(),
-                    ctime(),
-                    False,
-                    None
-                )
-            )
+        except Exception:
+            self.setup_error = ErrorRecord(get_exception())
 
     def _verify_encoding(self, encoding):
         """Verify the encoding is okay."""
@@ -1507,7 +1533,7 @@ class Rummage(object):
                 self.files.append(f)
 
             if self.abort:
-                self.files.clear()
+                break
 
             if len(self.files) >= folder_limit:
                 count = folder_limit
@@ -1537,34 +1563,39 @@ class Rummage(object):
         self.idx = -1
         self.skipped = 0
 
-        if len(self.files):
-            # Single target
-            if len(self.search_params):
-                # Search the file
-                for result in self.search_file(self.target if self.buffer_input else None):
-                    yield result
-            else:
-                # Single file with no search pattern, so just return the file
-                self.records += 1
-                yield self._get_next_file()
+        if self.setup_error:
+            yield self.setup_error
         else:
-            # Directory to crawl
-            if len(self.search_params):
-                # Crawl directory and search files.
-                try:
-                    for result in self.walk_files():
+            if len(self.files):
+                # Single target
+                if len(self.search_params):
+                    # Search the file
+                    for result in self.search_file(self.target if self.buffer_input else None):
                         yield result
-                except Exception:  # pragma: no cover
-                    yield ErrorRecord(get_exception())
-            else:
-                # No search pattern, so just return files that *would* be searched.
-                for f in self.path_walker.imatch():
-                    self.idx += 1
+                else:
+                    # Single file with no search pattern, so just return the file
                     self.records += 1
-                    if isinstance(f, FileAttrRecord) and f.skipped:
-                        self.skipped += 1
-                    yield f
+                    yield self._get_next_file()
+            else:
+                # Directory to crawl
+                if len(self.search_params):
+                    # Crawl directory and search files.
+                    try:
+                        for result in self.walk_files():
+                            yield result
+                    except Exception:  # pragma: no cover
+                        yield ErrorRecord(get_exception())
+                else:
+                    # No search pattern, so just return files that *would* be searched.
+                    for f in self.path_walker.imatch():
+                        self.idx += 1
+                        self.records += 1
+                        if isinstance(f, FileAttrRecord) and f.skipped:
+                            self.skipped += 1
+                        yield f
+                        if self.abort:
+                            break
 
-                if self.abort:
-                    self.files.clear()
-                self.skipped = self.path_walker.get_skipped()
+                    if self.abort:
+                        self.files.clear()
+                    self.skipped = self.path_walker.get_skipped()
