@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """Tests for `rumcore`."""
-from __future__ import unicode_literals
 import unittest
 import os
 import re
@@ -11,7 +10,6 @@ import textwrap
 from backrefs import bre
 from backrefs import bregex
 from rummage.lib import rumcore as rc
-from rummage.lib.util import epoch_timestamp as epoch
 from rummage.lib.rumcore import text_decode as td
 from wcmatch import wcmatch
 from . import util
@@ -357,7 +355,7 @@ class TestDirWalker(_FileTest):
         self.mktemp('greater_than_0.txt.rum-bak', content=b'Content greater than 0.')
         self.mktemp('.hidden', 'a.txt')
         self.mktemp('.hidden', 'b.file')
-        self.default_flags = wcmatch.R | wcmatch.I | wcmatch.M
+        self.default_flags = wcmatch.R | wcmatch.I | wcmatch.M | wcmatch.SL
         self.errors = []
         self.skipped = 0
         self.files = []
@@ -378,11 +376,8 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.txt', None,
-            False, False, self.default_flags,
-            False, False,
-            None, None, None,
-            None, False
+            file_pattern='*.txt',
+            flags=self.default_flags
         )
 
         self.crawl_files(walker)
@@ -397,11 +392,8 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.*|-*.file', None,
-            False, False, self.default_flags,
-            False, False,
-            None, None, None,
-            None, False
+            file_pattern='*.*|-*.file',
+            flags=self.default_flags
         )
 
         self.crawl_files(walker)
@@ -415,11 +407,9 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.*|-*.file', None,
-            False, False, self.default_flags,
-            False, False,
-            None, None, None,
-            'rum-bak', False
+            file_pattern='*.*|-*.file',
+            flags=self.default_flags,
+            backup_location='rum-bak'
         )
 
         self.crawl_files(walker)
@@ -433,11 +423,8 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.txt', None,
-            True, False, self.default_flags,
-            False, False,
-            None, None, None,
-            None, False
+            file_pattern='*.txt',
+            flags=self.default_flags | wcmatch.RECURSIVE
         )
 
         self.crawl_files(walker)
@@ -452,11 +439,8 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.txt', None,
-            True, True, self.default_flags,
-            False, False,
-            None, None, None,
-            None, False
+            file_pattern='*.txt',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN
         )
 
         self.crawl_files(walker)
@@ -471,11 +455,9 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.txt', '.hidden',
-            True, True, self.default_flags,
-            False, False,
-            None, None, None,
-            None, False
+            file_pattern='*.txt',
+            exclude_pattern='.hidden',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN
         )
 
         self.crawl_files(walker)
@@ -490,11 +472,9 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.txt', '*|-.hidden',
-            True, True, self.default_flags,
-            False, False,
-            None, None, None,
-            None, False
+            file_pattern='*.txt',
+            exclude_pattern='*|-.hidden',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN
         )
 
         self.crawl_files(walker)
@@ -509,11 +489,10 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.txt', r'\.hidden',
-            True, True, self.default_flags,
-            False, True,
-            None, None, None,
-            None, False
+            file_pattern='*.txt',
+            exclude_pattern=r'\.hidden',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            folder_regex_exclude_match=True
         )
 
         self.crawl_files(walker)
@@ -528,11 +507,10 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'*.\x74\N{LATIN SMALL LETTER X}\u0074', r'\.\U00000068idden',
-            True, True, self.default_flags,
-            False, True,
-            None, None, None,
-            None, False
+            file_pattern=r'*.\x74\N{LATIN SMALL LETTER X}\u0074',
+            exclude_pattern=r'\.\U00000068idden',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            folder_regex_exclude_match=True
         )
 
         self.crawl_files(walker)
@@ -547,11 +525,9 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'.*?\.txt', None,
-            False, False, self.default_flags,
-            True, False,
-            None, None, None,
-            None, False
+            file_pattern=r'.*?\.txt',
+            flags=self.default_flags,
+            file_regex_match=True
         )
 
         self.crawl_files(walker)
@@ -567,12 +543,10 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'.*?\.txt', None,
-            False, False, self.default_flags,
-            True, False,
-            None, None, None,
-            None, False,
-            rc.BRE_MODE
+            file_pattern=r'.*?\.txt',
+            flags=self.default_flags,
+            file_regex_match=True,
+            regex_mode=rc.BRE_MODE
         )
 
         self.crawl_files(walker)
@@ -588,12 +562,10 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'.*?\.txt', None,
-            False, False, self.default_flags,
-            True, False,
-            None, None, None,
-            None, False,
-            rc.REGEX_MODE
+            file_pattern=r'.*?\.txt',
+            flags=self.default_flags,
+            file_regex_match=True,
+            regex_mode=rc.REGEX_MODE
         )
 
         self.crawl_files(walker)
@@ -609,12 +581,10 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'.*?\.txt', None,
-            False, False, self.default_flags,
-            True, False,
-            None, None, None,
-            None, False,
-            rc.BREGEX_MODE
+            file_pattern=r'.*?\.txt',
+            flags=self.default_flags,
+            file_regex_match=True,
+            regex_mode=rc.BREGEX_MODE
         )
 
         self.crawl_files(walker)
@@ -630,12 +600,10 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'.*?\.txt', None,
-            False, False, self.default_flags,
-            True, False,
-            None, None, None,
-            None, False,
-            -1
+            file_pattern=r'.*?\.txt',
+            flags=self.default_flags,
+            file_regex_match=True,
+            regex_ver=-1
         )
 
         self.crawl_files(walker)
@@ -651,11 +619,8 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.txt', None,
-            True, True, self.default_flags,
-            False, False,
-            None, None, None,
-            None, False
+            file_pattern='*.txt',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN
         )
 
         records = 0
@@ -670,11 +635,8 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            '*.txt*', None,
-            True, True, self.default_flags,
-            False, False,
-            None, None, None,
-            None, False
+            file_pattern='*.txt*',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN
         )
 
         walker.kill()
@@ -682,18 +644,16 @@ class TestDirWalker(_FileTest):
         for f in walker.imatch():
             records += 1
 
-        self.assertTrue(records == 1 or walker.get_skipped() == 1)
+        self.assertTrue(records == 0 or walker.get_skipped() == 0)
 
     def test_size_less(self):
         """Test size less than x."""
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'*.*', None,
-            True, True, self.default_flags,
-            False, False,
-            ("lt", 1), None, None,
-            None, False
+            file_pattern=r'*.*',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            size=("lt", 1)
         )
 
         self.crawl_files(walker)
@@ -707,11 +667,9 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'*.*', None,
-            True, True, self.default_flags,
-            False, False,
-            ("gt", 1), None, None,
-            None, False
+            file_pattern=r'*.*',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            size=("gt", 1)
         )
 
         self.crawl_files(walker)
@@ -725,11 +683,9 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'*.*', None,
-            True, True, self.default_flags,
-            False, False,
-            ("eq", 0), None, None,
-            None, False
+            file_pattern=r'*.*',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            size=("eq", 0)
         )
 
         self.crawl_files(walker)
@@ -746,11 +702,9 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'*.*', None,
-            True, True, self.default_flags,
-            False, False,
-            None, ("lt", epoch.local_time_to_epoch_timestamp(date, '00:00:00')), None,
-            None, False
+            file_pattern=r'*.*',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            modified=("lt", rc.util.local_time_to_epoch_timestamp(date, '00:00:00'))
         )
 
         self.crawl_files(walker)
@@ -764,11 +718,9 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'*.*', None,
-            True, True, self.default_flags,
-            False, False,
-            None, ("gt", epoch.local_time_to_epoch_timestamp('07/07/1980', '00:00:00')), None,
-            None, False
+            file_pattern=r'*.*',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            modified=("gt", rc.util.local_time_to_epoch_timestamp('07/07/1980', '00:00:00'))
         )
 
         self.crawl_files(walker)
@@ -786,10 +738,8 @@ class TestDirWalker(_FileTest):
         walker = rc._DirWalker(
             self.tempdir,
             r'*.*', None,
-            True, True, self.default_flags,
-            False, False,
-            None, None, ("lt", epoch.local_time_to_epoch_timestamp(date, '00:00:00')),
-            None, False
+            self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            created=("lt", rc.util.local_time_to_epoch_timestamp(date, '00:00:00'))
         )
 
         self.crawl_files(walker)
@@ -803,11 +753,9 @@ class TestDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'*.*', None,
-            True, True, self.default_flags,
-            False, False,
-            None, None, ("gt", epoch.local_time_to_epoch_timestamp('07/07/1980', '00:00:00')),
-            None, False
+            file_pattern=r'*.*',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            created=("gt", rc.util.local_time_to_epoch_timestamp('07/07/1980', '00:00:00'))
         )
 
         self.crawl_files(walker)
@@ -816,6 +764,33 @@ class TestDirWalker(_FileTest):
         self.assertEqual(self.skipped, 0)
         self.assertEqual(len(self.files), 6)
 
+    def test_exceed_limit(self):
+        """Test exceeding the limit."""
+
+        with self.assertRaises(wcmatch._wcparse.PatternLimitException):
+            rc._DirWalker(
+                self.tempdir,
+                file_pattern='*.*|-*.file',
+                flags=self.default_flags,
+                limit=1
+            )
+
+    def test_no_limit(self):
+        """Test no limit search."""
+
+        walker = rc._DirWalker(
+            self.tempdir,
+            file_pattern='*.*|-*.file',
+            flags=self.default_flags,
+            limit=0
+        )
+
+        self.crawl_files(walker)
+
+        self.assertEqual(len(self.errors), 0)
+        self.assertEqual(self.skipped, 2)
+        self.assertEqual(len(self.files), 2)
+
 
 class TestHiddenDirWalker(_FileTest):
     """Test the `_DirWalker` class."""
@@ -847,11 +822,9 @@ class TestHiddenDirWalker(_FileTest):
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'*.txt', None,
-            True, True, self.default_flags,
-            False, False,
-            None, None, None,
-            None, True
+            file_pattern=r'*.txt',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            backup_to_folder=True
         )
 
         self.crawl_files(walker)
@@ -861,15 +834,14 @@ class TestHiddenDirWalker(_FileTest):
         self.assertEqual(len(self.files), 2)
 
     def test_backup_folder_with_backup(self):
-        """Test directory search with backup disabled and folder backup."""
+        """Test directory search with backup and folder backup."""
 
         walker = rc._DirWalker(
             self.tempdir,
-            r'*.txt', None,
-            True, True, self.default_flags,
-            False, False,
-            None, None, None,
-            '.rum-bak', True
+            file_pattern=r'*.txt',
+            flags=self.default_flags | wcmatch.RECURSIVE | wcmatch.HIDDEN,
+            backup_location='.rum-bak',
+            backup_to_folder=True
         )
 
         self.crawl_files(walker)
@@ -886,12 +858,13 @@ class TestFileSearch(_FileTest):
         """Get the file attributes."""
 
         name = self.norm(*path)
+        c_time, m_time = rc.util.get_stat(name)[:2]
         return rc.FileAttrRecord(
             name,
             os.path.splitext(name)[1].lower().lstrip('.'),
             os.path.getsize(name),
-            rc.getmtime(name),
-            rc.getctime(name),
+            m_time,
+            c_time,
             False,
             None
         )
